# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"REGION": "app.ipynb",
         "IDENTITY_POOL_ID": "app.ipynb",
         "USER_POOL_ID": "app.ipynb",
         "ACCOUNT_ID": "app.ipynb",
         "CLIENT_ID": "app.ipynb",
         "CLIENT_SECRET": "app.ipynb",
         "COMPULSARY_INPUTS": "app.ipynb",
         "cognito": "app.ipynb",
         "CreateCashier": "app.ipynb",
         "createCashier": "app.ipynb",
         "Auth": "app.ipynb",
         "auth": "app.ipynb",
         "Confirm": "app.ipynb",
         "confirm": "cognito.ipynb",
         "GetProfile": "app.ipynb",
         "getProfile": "app.ipynb",
         "UpdateProfile": "app.ipynb",
         "updateProfile": "app.ipynb",
         "SetPassword": "app.ipynb",
         "setPassword": "app.ipynb",
         "unauth": "app.ipynb",
         "DeleteUser": "app.ipynb",
         "deleteUser": "cognito.ipynb",
         "refresh": "app.ipynb",
         "Cognito": "cognito.ipynb",
         "addUser": "cognito.ipynb",
         "credenFromIdToken": "cognito.ipynb",
         "login": "cognito.ipynb",
         "unAuthCreden": "cognito.ipynb",
         "getAttribute": "cognito.ipynb",
         "loginWithFb": "cognito.ipynb",
         "addVillaEmployee": "cognito.ipynb",
         "update": "cognito.ipynb",
         "refreshToken": "cognito.ipynb",
         "getSecretHash": "cognito.ipynb",
         "disableUser": "cognito.ipynb",
         "enableUser": "cognito.ipynb",
         "setNewPassword": "cognito.ipynb",
         "updateAttribute": "cognito.ipynb"}

modules = ["app.py",
           "cognito.py"]

doc_url = "https://thanakijwanavit.github.io/pynamoLogger/"

git_url = "https://github.com/thanakijwanavit/pynamologger/tree/master/"

def custom_doc_links(name): return None
